@@ -66,7 +66,7 @@ def chrome_open_mobile(chrome_options=[], userdata_path=r"c:\chrome_mobile"):
     return driver
 
 
-def chrome_open(chrome_options=[], userdata_path=r"c:\chrome_userdata", download_path=r"C:\Users\james\Downloads"):
+def chrome_open(chrome_options=[], userdata_path=None, download_path=r"C:\Users\james\Downloads"):
     options = webdriver.ChromeOptions()
     options.add_argument('--no-sandbox')
     options.add_argument('--disable-dev-shm-usage')
@@ -257,6 +257,7 @@ def reuse_chrome_example_test():
     driver2.get("https://www.baidu.com")
 
 def save_cookies(driver, cookie_file):
+    # pickle.dump(driver.get_cookies() , open(cookie_file,"wb"))
     cookies_src  = driver.get_cookies()
     cookies = {}
     for item in cookies_src:
